==> fet_6.7.6.orig.tar.bz2: fet-6.7.6/src/interface/addconstraintteachersmaxmorningsperweekform.cpp <==
/***************************************************************************
                          addconstraintteachersmaxmorningsperweekform.cpp  -  description
                             -------------------
    begin                : June 2009
    copyright            : (C) 2009 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include <QMessageBox>

#include "longtextmessagebox.h"

#include "addconstraintteachersmaxmorningsperweekform.h"
#include "timeconstraint.h"

AddConstraintTeachersMaxMorningsPerWeekForm::AddConstraintTeachersMaxMorningsPerWeekForm(QWidget* parent): QDialog(parent)
{
	setupUi(this);

	addConstraintPushButton->setDefault(true);

	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));

	centerWidgetOnScreen(this);
	restoreFETDialogGeometry(this);
	
	updateMaxMorningsSpinBox();
}

AddConstraintTeachersMaxMorningsPerWeekForm::~AddConstraintTeachersMaxMorningsPerWeekForm()
{
	saveFETDialogGeometry(this);
}

void AddConstraintTeachersMaxMorningsPerWeekForm::updateMaxMorningsSpinBox(){
	maxMorningsSpinBox->setMinimum(1);
	maxMorningsSpinBox->setMaximum(gt.rules.nDaysPerWeek/2);
	maxMorningsSpinBox->setValue(gt.rules.nDaysPerWeek/2);
}

void AddConstraintTeachersMaxMorningsPerWeekForm::addCurrentConstraint()
{
	TimeConstraint *ctr=nullptr;

	double weight;
	QString tmp=weightLineEdit->text();
	weight_sscanf(tmp, "%lf", &weight);
	if(weight<0.0 || weight>100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage)"));
		return;
	}
	if(weight!=100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage) - it has to be 100%"));
		return;
	}
	
	int max_mornings=maxMorningsSpinBox->value();

	ctr=new ConstraintTeachersMaxMorningsPerWeek(weight, max_mornings);

	bool tmp2=gt.rules.addTimeConstraint(ctr);
	if(tmp2)
		LongTextMessageBox::information(this, tr("FET information"),
			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
	else{
		QMessageBox::warning(this, tr("FET information"),
			tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/addconstraintteachersmaxmorningsperweekform.cpp <==
/***************************************************************************
                          addconstraintteachersmaxmorningsperweekform.cpp  -  description
                             -------------------
    begin                : June 2009
    copyright            : (C) 2009 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include <QMessageBox>

#include "longtextmessagebox.h"

#include "addconstraintteachersmaxmorningsperweekform.h"
#include "timeconstraint.h"

AddConstraintTeachersMaxMorningsPerWeekForm::AddConstraintTeachersMaxMorningsPerWeekForm(QWidget* parent): QDialog(parent)
{
	setupUi(this);

	addConstraintPushButton->setDefault(true);

	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));

	centerWidgetOnScreen(this);
	restoreFETDialogGeometry(this);
	
	updateMaxMorningsSpinBox();
}

AddConstraintTeachersMaxMorningsPerWeekForm::~AddConstraintTeachersMaxMorningsPerWeekForm()
{
	saveFETDialogGeometry(this);
}

void AddConstraintTeachersMaxMorningsPerWeekForm::updateMaxMorningsSpinBox(){
	maxMorningsSpinBox->setMinimum(1);
	maxMorningsSpinBox->setMaximum(gt.rules.nDaysPerWeek/2);
	maxMorningsSpinBox->setValue(gt.rules.nDaysPerWeek/2);
}

void AddConstraintTeachersMaxMorningsPerWeekForm::addCurrentConstraint()
{
	TimeConstraint *ctr=nullptr;

	double weight;
	QString tmp=weightLineEdit->text();
	weight_sscanf(tmp, "%lf", &weight);
	if(weight<0.0 || weight>100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage)"));
		return;
	}
	if(weight!=100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage) - it has to be 100%"));
		return;
	}
	
	int max_mornings=maxMorningsSpinBox->value();

	ctr=new ConstraintTeachersMaxMorningsPerWeek(weight, max_mornings);

	bool tmp2=gt.rules.addTimeConstraint(ctr);
	if(tmp2)
		LongTextMessageBox::information(this, tr("FET information"),
			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
	else{
		QMessageBox::warning(this, tr("FET information"),
			tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}
